==> unforward-0.1.8.tar.gz: unforward-0.1.8/unforward/test/examples.py <==
#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

examples =  [
                {
                    "client": ["outlook", "iphone"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/outlook_express_forward.html",
                    "result" : {'sender' : 'laolaw@lao.on.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["gmail"],
                    "file" : "examples/gmail_forward_1.html",
                    "result" : {'sender' : 'jamie@moonrider.com',
                                'body'   : '<p> Original Email</p>'}
                },
                {
                    "client": ["gmail"],
                    "file" : "examples/gmail_forward_3.html",
                    "result" : {'sender' : 'builds@drone.io',
                                'body'   : '<p>Build Failed</p>'}
                },
                {
                    "client": ["blackberry"],
                    "file" : "examples/blackberry_forward.html",
                    "result" : {'sender' : 'efenkell@gmail.com',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["iphone", "outlook"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/iphone_forward.html",
                    "result" : {'sender' : 'dmz@ryerson.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["lotusnotes"],
                    "file" : "examples/lotus_notes_forward.txt",
                    "result" : {'sender' : 'jamie@getsensibill.com',
                                'body'   : 'Original Email'}
                },
                {
                    "client": ["yahoo"],
                    "file" : "examples/yahoo_forward.html",
                    "result" : {'sender' : 'noreply@3scale.net',
                                'body'   : '<p> Original Email</p>'}
                }
            ]

==> unforward-0.1.9.tar.gz: unforward-0.1.9/unforward/test/examples.py <==
#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#

examples =  [
                {
                    "client": ["outlook", "iphone"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/outlook_express_forward.html",
                    "result" : {'sender' : 'laolaw@lao.on.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["gmail"],
                    "file" : "examples/gmail_forward_1.html",
                    "result" : {'sender' : 'jamie@moonrider.com',
                                'body'   : '<p> Original Email</p>'}
                },
                {
                    "client": ["gmail"],
                    "file" : "examples/gmail_forward_3.html",
                    "result" : {'sender' : 'builds@drone.io',
                                'body'   : '<br/><p>Build Failed</p>'}
                },
                {
                    "client": ["gmail"],
                    "file" : "examples/gmail_forward_5.html",
                    "result" : {'sender' : 'customercare_canada@homedepot.com',
                                'body'   : '<p>TEST</p>'}
                },
                {
                    "client": ["blackberry"],
                    "file" : "examples/blackberry_forward.html",
                    "result" : {'sender' : 'efenkell@gmail.com',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["iphone", "outlook"], # Outlook and iphone forward in exactly the same way
                    "file" : "examples/iphone_forward.html",
                    "result" : {'sender' : 'dmz@ryerson.ca',
                                'body'   : '<p>Original Email</p>'}
                },
                {
                    "client": ["lotusnotes"],
                    "file" : "examples/lotus_notes_forward.txt",
                    "result" : {'sender' : 'jamie@getsensibill.com',
                                'body'   : 'Original Email'}
                },
                {
                    "client": ["yahoo"],
                    "file" : "examples/yahoo_forward.html",
                    "result" : {'sender' : 'noreply@3scale.net',
                                'body'   : '<p> Original Email</p>'}
                }
            ]
